@@ -6,8 +6,8 @@ from dataclasses import (
 )
 from google.cloud import storage
 from typing import List
-from gdo_arch_utils.utils.log_utils import LogUtils as log_utils
-from gdo_arch_utils.utils.traceback_utils import TracebackUtils as traceback_utils
+from ..utils.log_utils import LogUtils as log_utils
+from ..utils.traceback_utils import TracebackUtils as traceback_utils
 
 logger = log_utils.get_logger()
 
