@@ -1,8 +1,8 @@
 import pysftp
 from dataclasses import dataclass
-from gdo_arch_utils.utils.file_utils import FileUtils as file_utils
-from gdo_arch_utils.utils.log_utils import LogUtils as log_utils
-from gdo_arch_utils.utils.traceback_utils import TracebackUtils as traceback_utils
+from ..utils.file_utils import FileUtils as file_utils
+from ..utils.log_utils import LogUtils as log_utils
+from ..utils.traceback_utils import TracebackUtils as traceback_utils
 logger = log_utils.get_logger()
 
 
