@@ -1,7 +1,7 @@
 import time
 
 from functools import wraps
-from gdo_arch_utils.utils.log_utils import LogUtils as log_utils
+from ..utils.log_utils import LogUtils as log_utils
 
 logger = log_utils.get_logger()
 
