@@ -1,9 +1,9 @@
-from gdo_arch_utils.utils.file_utils import FileUtils as file_utils
+from .file_utils import FileUtils as file_utils
 from email.message import EmailMessage
 import smtplib
 import traceback
 from dataclasses import dataclass
-from gdo_arch_utils.utils.log_utils import LogUtils as log_utils
+from .log_utils import LogUtils as log_utils
 
 logger = log_utils.get_logger()
 
