@@ -6,7 +6,7 @@ from os import (
 )
 from os.path import getsize
 import json
-from gdo_arch_utils.utils.log_utils import LogUtils as log_utils
+from .log_utils import LogUtils as log_utils
 
 logger = log_utils.get_logger()
 
