@@ -1,8 +1,8 @@
 from dataclasses import dataclass
 
-from gdo_arch_utils.connections.gcs_client_connection import GcsClientConnection
-from gdo_arch_utils.decorators.timed_decorator import timed
-from gdo_arch_utils.utils.log_utils import LogUtils as log_utils
+from ..connections.gcs_client_connection import GcsClientConnection
+from ..decorators.timed_decorator import timed
+from .log_utils import LogUtils as log_utils
 
 logger = log_utils.get_logger()
 
