@@ -1,6 +1,6 @@
 from enum import Enum
 from typing import List
-from gdo_arch_utils.utils.log_utils import LogUtils as log_utils
+from .log_utils import LogUtils as log_utils
 
 logger = log_utils.get_logger()
 
