@@ -1,8 +1,8 @@
-from gdo_arch_utils.dto.manifest import ManifestDTO
+from ..dto.manifest import ManifestDTO
 from datetime import datetime
-from gdo_arch_utils.utils.file_utils import FileUtils as file_utils
+from .file_utils import FileUtils as file_utils
 from typing import List
-from gdo_arch_utils.utils.log_utils import LogUtils as log_utils
+from .log_utils import LogUtils as log_utils
 
 logger = log_utils.get_logger()
 
