@@ -1,9 +1,9 @@
 from dataclasses import dataclass
 
-from gdo_arch_utils.connections.sftp_connection import SftpConnection
-from gdo_arch_utils.decorators.timed_decorator import timed
-from gdo_arch_utils.utils.log_utils import LogUtils as log_utils
-from gdo_arch_utils.utils.file_utils import FileUtils as file_utils
+from ..connections.sftp_connection import SftpConnection
+from ..decorators.timed_decorator import timed
+from .log_utils import LogUtils as log_utils
+from .file_utils import FileUtils as file_utils
 
 logger = log_utils.get_logger()
 
