@@ -1,10 +1,10 @@
 from dataclasses import dataclass
 from typing import List
-from gdo_arch_utils.decorators.timed_decorator import timed
-from gdo_arch_utils.connections.snowflake_connection import SnowflakeConnection
-from gdo_arch_utils.utils.list_utils import ListUtils as list_utils
+from ..decorators.timed_decorator import timed
+from ..connections.snowflake_connection import SnowflakeConnection
+from .list_utils import ListUtils as list_utils
 from tabulate import tabulate
-from gdo_arch_utils.utils.log_utils import LogUtils as log_utils
+from .log_utils import LogUtils as log_utils
 
 logger = log_utils.get_logger()
 
